/*
 * Copyright (c) 2014 Hewlett-Packard Development Company, L.P.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package monasca.api.resource.exception;

import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

import monasca.api.resource.exception.Exceptions.FaultType;

/**
 * Adapted from Dropwizard's LoggingExceptionMapper.
 * 
 * @param <E> Exception type
 */
@Provider
public class ThrowableExceptionMapper<E extends Throwable> implements ExceptionMapper<E> {
  @Override
  public Response toResponse(E exception) {
    if (exception instanceof WebApplicationException)
      return ((WebApplicationException) exception).getResponse();

    return Response
        .status(Status.INTERNAL_SERVER_ERROR)
        .type(MediaType.APPLICATION_JSON)
        .entity(
            Exceptions.buildLoggedErrorMessage(FaultType.SERVER_ERROR,
                "An internal server error occurred", null, exception)).build();
  }
}
